@@ -3,7 +3,8 @@
 
 .onAttach <- function(libname, pkgname)
 {
-    msg <- paste('\nFor help getting started, see <https://doi.org/10.31234/osf.io/eht87> \n\n')
+    msg <- styletext(styletext("\nSemNetDictionaries", defaults = "underline"), defaults = "bold")
+    msg <- paste(msg, '\nFor help getting started, see <https://doi.org/10.31234/osf.io/eht87> \n\n')
     msg <- paste(msg,"Submit your own dictionary and moniker glossaries to:\n <https://github.com/AlexChristensen/SemNetDictionaries/issues/new/choose>\n")
     packageStartupMessage(msg)
 }
\ No newline at end of file
