@@ -1,15 +1,16 @@
 ## ----setup, include=FALSE-----------------------------------------------------
 knitr::opts_chunk$set(echo = TRUE)
 library(htmlTable)
+library(SemNetDictionaries)
 
 ## ----tab1, echo = FALSE, eval = TRUE, comment = NA, warning = FALSE-----------
-output <- matrix(c("animals", "1,021", "Category",
-                   "fruits", "488", "Category",
-                   "general", "370,103", "All-purpose",
-                   "good", "284", "Synonym",
-                   "hot", "281", "Synonym",
-                   "jobs", "1,471", "Category",
-                   "vegetables", "284", "Category"),
+output <- matrix(c("animals", length(animals.dictionary), "Category",
+                   "fruits", length(fruits.dictionary), "Category",
+                   "general", length(general.dictionary), "All-purpose",
+                   "good", length(good.dictionary), "Synonym",
+                   "hot", length(hot.dictionary), "Synonym",
+                   "jobs", length(jobs.dictionary), "Category",
+                   "vegetables", length(vegetables.dictionary), "Category"),
                  ncol = 3, byrow = TRUE)
 
 
